r200137 - Update docstrings following the param name change in r200132

Alp Toker alp at nuanti.com
Sat Jan 25 22:41:58 PST 2014


Author: alp
Date: Sun Jan 26 00:41:58 2014
New Revision: 200137

URL: http://llvm.org/viewvc/llvm-project?rev=200137&view=rev
Log:
Update docstrings following the param name change in r200132

Modified:
    cfe/trunk/include/clang/Basic/Diagnostic.h
    cfe/trunk/lib/Basic/DiagnosticIDs.cpp

Modified: cfe/trunk/include/clang/Basic/Diagnostic.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/Basic/Diagnostic.h?rev=200137&r1=200136&r2=200137&view=diff
==============================================================================
--- cfe/trunk/include/clang/Basic/Diagnostic.h (original)
+++ cfe/trunk/include/clang/Basic/Diagnostic.h Sun Jan 26 00:41:58 2014
@@ -593,8 +593,8 @@ public:
   /// If this is the first request for this diagnostic, it is registered and
   /// created, otherwise the existing ID is returned.
   ///
-  /// \param Message A fixed diagnostic format string that will be hashed and
-  /// mapped to a unique DiagID.
+  /// \param FormatString A fixed diagnostic format string that will be hashed
+  /// and mapped to a unique DiagID.
   template <unsigned N>
   unsigned getCustomDiagID(Level L, const char (&FormatString)[N]) {
     return Diags->getCustomDiagID((DiagnosticIDs::Level)L,

Modified: cfe/trunk/lib/Basic/DiagnosticIDs.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Basic/DiagnosticIDs.cpp?rev=200137&r1=200136&r2=200137&view=diff
==============================================================================
--- cfe/trunk/lib/Basic/DiagnosticIDs.cpp (original)
+++ cfe/trunk/lib/Basic/DiagnosticIDs.cpp Sun Jan 26 00:41:58 2014
@@ -312,12 +312,12 @@ DiagnosticIDs::~DiagnosticIDs() {
 /// and level.  If this is the first request for this diagnostic, it is
 /// registered and created, otherwise the existing ID is returned.
 ///
 /// \param Message A fixed diagnostic format string that will be hashed and
 /// mapped to a unique DiagID.
-unsigned DiagnosticIDs::getCustomDiagID(Level L, StringRef Message) {
+unsigned DiagnosticIDs::getCustomDiagID(Level L, StringRef FormatString) {
   if (CustomDiagInfo == 0)
     CustomDiagInfo = new diag::CustomDiagInfo();
-  return CustomDiagInfo->getOrCreateDiagID(L, Message, *this);
+  return CustomDiagInfo->getOrCreateDiagID(L, FormatString, *this);
 }
 
 
@@ -312,12 +312,12 @@ DiagnosticIDs::~DiagnosticIDs() {
 /// registered and created, otherwise the existing ID is returned.
 ///
-/// \param Message A fixed diagnostic format string that will be hashed and
+/// \param FormatString A fixed diagnostic format string that will be hashed and
 /// mapped to a unique DiagID.





More information about the cfe-commits mailing list